/* -----------------------------------------------------------------------------
 * Copyright (c) 2013 - 2015 ARM Ltd.
 *
 * This software is provided 'as-is', without any express or implied warranty. 
 * In no event will the authors be held liable for any damages arising from 
 * the use of this software. Permission is granted to anyone to use this 
 * software for any purpose, including commercial applications, and to alter 
 * it and redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not 
 *    claim that you wrote the original software. If you use this software in
 *    a product, an acknowledgment in the product documentation would be 
 *    appreciated but is not required. 
 * 
 * 2. Altered source versions must be plainly marked as such, and must not be 
 *    misrepresented as being the original software. 
 * 
 * 3. This notice may not be removed or altered from any source distribution.
 *
 *
 * $Date:        27. October 2015
 * $Revision:    V1.1
 *  
 * Driver:       Driver_Flash# (default: Driver_Flash0)
 * Project:      Flash Device Description for M29EW 128Mb (16-bit)
 *               Part Number: JS28F128M29EW, PC28F128M29EW, RC28F128M29EW
 * -------------------------------------------------------------------- */

#define FLASH_SECTOR_COUNT      ((uint32_t)128) /* Number of sectors */
#define FLASH_SECTOR_SIZE       ((uint32_t)0)   /* FLASH_SECTORS information used */
#define FLASH_PAGE_SIZE         ((uint32_t)2)   /* Programming page size in bytes */
#define FLASH_PROGRAM_UNIT      ((uint32_t)2)   /* Smallest programmable unit in bytes */
#define FLASH_ERASED_VALUE      ((uint8_t)0xFF) /* Contents of erased memory */

#define FLASH_SECTORS {                                                 \
  ARM_FLASH_SECTOR_INFO(0x000000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x020000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x040000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x060000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x080000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x0A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x0C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x0E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x100000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x120000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x140000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x160000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x180000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x1A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x1C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x1E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x200000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x220000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x240000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x260000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x280000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x2A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x2C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x2E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x300000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x320000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x340000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x360000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x380000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x3A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x3C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x3E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x400000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x420000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x440000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x460000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x480000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x4A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x4C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x4E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x500000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x520000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x540000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x560000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x580000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x5A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x5C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x5E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x600000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x620000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x640000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x660000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x680000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x6A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x6C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x6E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x700000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x720000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x740000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x760000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x780000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x7A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x7C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x7E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x800000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x820000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x840000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x860000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x880000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x8A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x8C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x8E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x900000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x920000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x940000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x960000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x980000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x9A0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x9C0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0x9E0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA00000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA20000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA40000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA60000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xA80000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xAA0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xAC0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xAE0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB00000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB20000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB40000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB60000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xB80000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xBA0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xBC0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xBE0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC00000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC20000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC40000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC60000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xC80000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xCA0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xCC0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xCE0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD00000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD20000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD40000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD60000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xD80000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xDA0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xDC0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xDE0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE00000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE20000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE40000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE60000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xE80000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xEA0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xEC0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xEE0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF00000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF20000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF40000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF60000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xF80000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xFA0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xFC0000UL, 0x20000UL), /* Sector size 128kB */ \
  ARM_FLASH_SECTOR_INFO(0xFE0000UL, 0x20000UL)  /* Sector size 128kB */ \
}
